@@ -22,7 +22,7 @@ typedef enum {
 	FILE_FL_LAST
 } FileFormatLevel;
 GType go_file_saver_level_get_type (void);
-#define GO_FILE_SAVER_LEVEL_TYPE (go_file_saver_level_get_type ())
+#define GO_TYPE_FILE_SAVER_LEVEL (go_file_saver_level_get_type ())
 
 /*
  * FileSaveScope specifies what information file saver can save in a file.
@@ -36,7 +36,7 @@ typedef enum {
 	FILE_SAVE_LAST
 } FileSaveScope;
 GType go_file_saver_scope_get_type (void);
-#define GO_FILE_SAVER_SCOPE_TYPE (go_file_saver_scope_get_type ())
+#define GO_TYPE_FILE_SAVER_SCOPE (go_file_saver_scope_get_type ())
 
 /*
  * GOFileOpener
@@ -46,43 +46,44 @@ typedef struct _GOFileOpenerClass GOFileOpenerClass;
 
 #define TYPE_GO_FILE_OPENER             (go_file_opener_get_type ())
 #define GO_FILE_OPENER(obj)             (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GO_FILE_OPENER, GOFileOpener))
-#define IS_GO_FILE_OPENER(obj)          (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GO_FILE_OPENER))
+#define GO_IS_FILE_OPENER(obj)          (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GO_FILE_OPENER))
 
 typedef gboolean (*GOFileOpenerProbeFunc) (GOFileOpener const *fo,
 					    GsfInput *input,
 					    FileProbeLevel pl);
 typedef void     (*GOFileOpenerOpenFunc) (GOFileOpener const *fo,
-					   IOContext *io_context,
-					   gpointer FIXME_FIXME_workbook_view,
-					   GsfInput *input);
+					  IOContext *io_context,
+					  gpointer FIXME_FIXME_workbook_view,
+					  GsfInput *input);
 typedef void     (*GOFileOpenerOpenFuncWithEnc) (GOFileOpener const *fo,
-						  gchar const *enc,
-						  IOContext *io_context,
-						  gpointer FIXME_FIXME_workbook_view,
-						  GsfInput *input);
+						 gchar const *enc,
+						 IOContext *io_context,
+						 gpointer FIXME_workbook_view,
+						 GsfInput *input);
 
 GType go_file_opener_get_type (void);
 
 GOFileOpener *go_file_opener_new (char const *id,
-				    char const *description,
-				    GSList *suffixes,
-				    GSList *mimes,
-				    GOFileOpenerProbeFunc probe_func,
-				    GOFileOpenerOpenFunc open_func);
+				  char const *description,
+				  GSList *suffixes,
+				  GSList *mimes,
+				  GOFileOpenerProbeFunc probe_func,
+				  GOFileOpenerOpenFunc open_func);
+
 GOFileOpener *go_file_opener_new_with_enc (char const *id,
-					     char const *description,
-					     GSList *suffixes,
-					     GSList *mimes,
-					     GOFileOpenerProbeFunc probe_func,
-					     GOFileOpenerOpenFuncWithEnc open_func);
+					   char const *description,
+					   GSList *suffixes,
+					   GSList *mimes,
+					   GOFileOpenerProbeFunc probe_func,
+					   GOFileOpenerOpenFuncWithEnc open_func);
 
 
 gboolean     go_file_opener_probe (GOFileOpener const *fo, GsfInput *input,
 				    FileProbeLevel pl);
 void         go_file_opener_open (GOFileOpener const *fo, gchar const *opt_enc,
-				   IOContext *io_context,
-				   gpointer  FIXME_FIXME_workbook_view,
-				   GsfInput *input);
+				  IOContext *io_context,
+				  gpointer FIXME_workbook_view,
+				  GsfInput *input);
 
 char const *go_file_opener_get_id		  (GOFileOpener const *fo);
 char const *go_file_opener_get_description	  (GOFileOpener const *fo);
@@ -100,26 +101,33 @@ typedef struct _GOFileSaverClass GOFileSaverClass;
 
 #define TYPE_GO_FILE_SAVER             (go_file_saver_get_type ())
 #define GO_FILE_SAVER(obj)             (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GO_FILE_SAVER, GOFileSaver))
-#define IS_GO_FILE_SAVER(obj)          (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GO_FILE_SAVER))
+#define GO_IS_FILE_SAVER(obj)          (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GO_FILE_SAVER))
 
 typedef void (*GOFileSaverSaveFunc) (GOFileSaver const *fs,
-				      IOContext *io_context,
-				      gconstpointer FIXME_FIXME_workbook_view,
-				      GsfOutput *output);
+				     IOContext *io_context,
+				     gconstpointer FIXME_FIXME_workbook_view,
+				     GsfOutput *output);
+
 GType go_file_saver_get_type (void);
 
 GOFileSaver *go_file_saver_new (char const *id,
-				  char const *extension,
-				  char const *description,
-				  FileFormatLevel level,
-				  GOFileSaverSaveFunc save_func);
+				char const *extension,
+				char const *description,
+				FileFormatLevel level,
+				GOFileSaverSaveFunc save_func);
+
 
 void          go_file_saver_set_save_scope (GOFileSaver *fs, FileSaveScope scope);
 FileSaveScope go_file_saver_get_save_scope (GOFileSaver const *fs);
 
+gboolean     go_file_saver_set_export_options (GOFileSaver *fs,
+					       GODoc *doc,
+					       const char *options,
+					       GError **err);
+
 void         go_file_saver_save (GOFileSaver const *fs, IOContext *io_context,
-				  gconstpointer FIXME_FIXME_workbook_view,
-				  GsfOutput *output);
+				 gconstpointer FIXME_workbook_view,
+				 GsfOutput *output);
 void         go_file_saver_set_overwrite_files	(GOFileSaver *fs,
 						 gboolean overwrite);
 char const *go_file_saver_get_id	  	(GOFileSaver const *fs);
