@@ -15,7 +15,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 #ifndef GO_DATA_SIMPLE_H
@@ -26,17 +26,17 @@
 
 G_BEGIN_DECLS
 
-#define GO_DATA_SCALAR_VAL_TYPE  (go_data_scalar_val_get_type ())
-#define GO_DATA_SCALAR_VAL(o)	 (G_TYPE_CHECK_INSTANCE_CAST ((o), GO_DATA_SCALAR_VAL_TYPE, GODataScalarVal))
-#define IS_GO_DATA_SCALAR_VAL(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), GO_DATA_SCALAR_VAL_TYPE))
+#define GO_TYPE_DATA_SCALAR_VAL  (go_data_scalar_val_get_type ())
+#define GO_DATA_SCALAR_VAL(o)	 (G_TYPE_CHECK_INSTANCE_CAST ((o), GO_TYPE_DATA_SCALAR_VAL, GODataScalarVal))
+#define GO_IS_DATA_SCALAR_VAL(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), GO_TYPE_DATA_SCALAR_VAL))
 
 typedef struct _GODataScalarVal GODataScalarVal;
 GType	 go_data_scalar_val_get_type (void);
 GOData	*go_data_scalar_val_new      (double val);
 
-#define GO_DATA_SCALAR_STR_TYPE  (go_data_scalar_str_get_type ())
-#define GO_DATA_SCALAR_STR(o)	 (G_TYPE_CHECK_INSTANCE_CAST ((o), GO_DATA_SCALAR_STR_TYPE, GODataScalarStr))
-#define IS_GO_DATA_SCALAR_STR(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), GO_DATA_SCALAR_STR_TYPE))
+#define GO_TYPE_DATA_SCALAR_STR  (go_data_scalar_str_get_type ())
+#define GO_DATA_SCALAR_STR(o)	 (G_TYPE_CHECK_INSTANCE_CAST ((o), GO_TYPE_DATA_SCALAR_STR, GODataScalarStr))
+#define GO_IS_DATA_SCALAR_STR(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), GO_TYPE_DATA_SCALAR_STR))
 
 typedef struct _GODataScalarStr GODataScalarStr;
 GType	 go_data_scalar_str_get_type (void);
@@ -44,17 +44,17 @@ GOData	*go_data_scalar_str_new      (char const *text, gboolean needs_free);
 void     go_data_scalar_str_set_str  (GODataScalarStr *str,
 				      char const *text, gboolean needs_free);
 
-#define GO_DATA_VECTOR_VAL_TYPE  (go_data_vector_val_get_type ())
-#define GO_DATA_VECTOR_VAL(o)	 (G_TYPE_CHECK_INSTANCE_CAST ((o), GO_DATA_VECTOR_VAL_TYPE, GODataVectorVal))
-#define IS_GO_DATA_VECTOR_VAL(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), GO_DATA_VECTOR_VAL_TYPE))
+#define GO_TYPE_DATA_VECTOR_VAL  (go_data_vector_val_get_type ())
+#define GO_DATA_VECTOR_VAL(o)	 (G_TYPE_CHECK_INSTANCE_CAST ((o), GO_TYPE_DATA_VECTOR_VAL, GODataVectorVal))
+#define GO_IS_DATA_VECTOR_VAL(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), GO_TYPE_DATA_VECTOR_VAL))
 
 typedef struct _GODataVectorVal GODataVectorVal;
 GType	 go_data_vector_val_get_type (void);
 GOData	*go_data_vector_val_new      (double *val, unsigned n, GDestroyNotify   notify);
 
-#define GO_DATA_VECTOR_STR_TYPE  (go_data_vector_str_get_type ())
-#define GO_DATA_VECTOR_STR(o)	 (G_TYPE_CHECK_INSTANCE_CAST ((o), GO_DATA_VECTOR_STR_TYPE, GODataVectorStr))
-#define IS_GO_DATA_VECTOR_STR(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), GO_DATA_VECTOR_STR_TYPE))
+#define GO_TYPE_DATA_VECTOR_STR  (go_data_vector_str_get_type ())
+#define GO_DATA_VECTOR_STR(o)	 (G_TYPE_CHECK_INSTANCE_CAST ((o), GO_TYPE_DATA_VECTOR_STR, GODataVectorStr))
+#define GO_IS_DATA_VECTOR_STR(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), GO_TYPE_DATA_VECTOR_STR))
 
 typedef struct _GODataVectorStr GODataVectorStr;
 GType	go_data_vector_str_get_type	      (void);
@@ -63,12 +63,12 @@ void    go_data_vector_str_set_translate_func (GODataVectorStr *vector,
 					       GOTranslateFunc  func,
 					       gpointer         data,
 					       GDestroyNotify   notify);
-void go_data_vector_str_set_translation_domain (GODataVectorStr *vec,
+void go_data_vector_str_set_translation_domain (GODataVectorStr *vector,
 						char const      *domain);
 
-#define GO_DATA_MATRIX_VAL_TYPE  (go_data_matrix_val_get_type ())
-#define GO_DATA_MATRIX_VAL(o)	 (G_TYPE_CHECK_INSTANCE_CAST ((o), GO_DATA_MATRIX_VAL_TYPE, GODataMatrixVal))
-#define IS_GO_DATA_MATRIX_VAL(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), GO_DATA_MATRIX_VAL_TYPE))
+#define GO_TYPE_DATA_MATRIX_VAL  (go_data_matrix_val_get_type ())
+#define GO_DATA_MATRIX_VAL(o)	 (G_TYPE_CHECK_INSTANCE_CAST ((o), GO_TYPE_DATA_MATRIX_VAL, GODataMatrixVal))
+#define GO_IS_DATA_MATRIX_VAL(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), GO_TYPE_DATA_MATRIX_VAL))
 
 typedef struct _GODataMatrixVal GODataMatrixVal;
 GType	 go_data_matrix_val_get_type (void);
