@@ -19,14 +19,8 @@
  * USA
  */
 
-#include <goffice/graph/gog-chart-map.h>
-#include <goffice/math/go-cspline.h>
-#include <goffice/math/go-math.h>
-#include <goffice/math/go-rangefunc.h>
-#include <goffice/utils/go-bezier.h>
-#include <goffice/utils/go-line.h>
-#include <goffice/utils/go-path.h>
-#include <goffice/utils/go-geometry.h>
+#include <goffice/goffice-config.h>
+#include <goffice/goffice.h>
 
 struct _GogChartMap {
 	GogChart 		*chart;
@@ -792,7 +786,7 @@ gog_chart_map_new (GogChart *chart, GogViewAllocation const *area,
 	GogChartMap *map;
 	GogAxisSet axis_set;
 
-	g_return_val_if_fail (IS_GOG_CHART (chart), NULL);
+	g_return_val_if_fail (GOG_IS_CHART (chart), NULL);
 	axis_set = gog_chart_get_axis_set (chart);
 	g_return_val_if_fail (axis_set != GOG_AXIS_SET_UNKNOWN &&
 			      axis_set != GOG_AXIS_SET_NONE, NULL);
