@@ -24,23 +24,11 @@
 #include <lsmmathmlmathelement.h>
 
 #include <goffice/goffice-config.h>
-#include <goffice/graph/gog-outlined-object.h>
-#include <goffice/utils/go-style.h>
-#include <goffice/graph/gog-renderer.h>
-#include <goffice/graph/gog-theme.h>
 #include <goffice/graph/gog-equation.h>
-#include <goffice/utils/go-persist.h>
-#include <goffice/utils/go-color.h>
-#include <goffice/utils/go-style.h>
-#include <goffice/utils/go-styled-object.h>
 
 #include <gsf/gsf-impl-utils.h>
 #include <glib/gi18n-lib.h>
 
-#ifdef GOFFICE_WITH_GTK
-#include <goffice/gtk/goffice-gtk.h>
-#endif
-
 enum {
 	EQUATION_PROP_0,
 	EQUATION_PROP_ITEX,
