@@ -25,11 +25,14 @@
 #include <goffice/graph/gog-view.h>
 #include <goffice/graph/gog-renderer.h>
 #include <goffice/graph/gog-chart.h>
-#include <goffice/graph/gog-style.h>
+#include <goffice/utils/go-style.h>
 #include <goffice/graph/gog-theme.h>
 #include <goffice/utils/go-color.h>
+#include <goffice/utils/go-styled-object.h>
+#include <goffice/math/go-math.h>
 #include <goffice/utils/go-marker.h>
-#include <goffice/utils/go-math.h>
+#include <goffice/utils/go-path.h>
+#include <goffice/utils/go-persist.h>
 #include <goffice/utils/go-units.h>
 
 #include <gsf/gsf-impl-utils.h>
@@ -158,20 +161,20 @@ gog_legend_update (GogObject *obj)
 
 static void
 gog_legend_populate_editor (GogObject *gobj, 
-			    GogEditor *editor, 
+			    GOEditor *editor, 
 			    GogDataAllocator *dalloc, 
 			    GOCmdContext *cc)
 {
 	static guint legend_pref_page = 0;
 
 	(GOG_OBJECT_CLASS(parent_klass)->populate_editor) (gobj, editor, dalloc, cc);
-	gog_editor_set_store_page (editor, &legend_pref_page);
+	go_editor_set_store_page (editor, &legend_pref_page);
 }
 
 static void
-gog_legend_init_style (GogStyledObject *gso, GogStyle *style)
+gog_legend_init_style (GogStyledObject *gso, GOStyle *style)
 {
-	style->interesting_fields = GOG_STYLE_OUTLINE | GOG_STYLE_FILL | GOG_STYLE_FONT;
+	style->interesting_fields = GO_STYLE_OUTLINE | GO_STYLE_FILL | GO_STYLE_FONT;
 	gog_theme_fillin_style (gog_object_get_theme (GOG_OBJECT (gso)),
 		style, GOG_OBJECT (gso), 0, FALSE);
 }
@@ -206,13 +209,13 @@ gog_legend_class_init (GogLegendClass *klass)
 			_("Swatch Size pts"),
 			_("size of the swatches in pts."),
 			0, G_MAXDOUBLE, 0, 
-			GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
 	g_object_class_install_property (gobject_klass, LEGEND_SWATCH_PADDING_PTS,
 		g_param_spec_double ("swatch-padding-pts", 
 			_("Swatch Padding pts"),
 			_("padding between the swatches in pts."),
 			0, G_MAXDOUBLE, 0, 
-			GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
 }
 
 static void
@@ -225,7 +228,7 @@ gog_legend_init (GogLegend *legend)
 
 GSF_CLASS (GogLegend, gog_legend,
 	   gog_legend_class_init, gog_legend_init,
-	   GOG_OUTLINED_OBJECT_TYPE)
+	   GOG_TYPE_OUTLINED_OBJECT)
 
 #define	GLV_ELEMENT_HEIGHT_EM		1.2	/* Legend element height, in font size */
 #define GLV_LINE_WIDTH_MAX_DEFAULT_EM	0.5	/* Maximum sample line width, in font size */
@@ -252,14 +255,14 @@ typedef struct {
 
 typedef GogOutlinedViewClass	GogLegendViewClass;
 
-#define GOG_LEGEND_VIEW_TYPE	(gog_legend_view_get_type ())
-#define GOG_LEGEND_VIEW(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_LEGEND_VIEW_TYPE, GogLegendView))
-#define IS_GOG_LEGEND_VIEW(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_LEGEND_VIEW_TYPE))
+#define GOG_TYPE_LEGEND_VIEW	(gog_legend_view_get_type ())
+#define GOG_LEGEND_VIEW(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_TYPE_LEGEND_VIEW, GogLegendView))
+#define GOG_IS_LEGEND_VIEW(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_TYPE_LEGEND_VIEW))
 
 static GogViewClass *lview_parent_klass;
 
 static void
-cb_size_elements (unsigned i, GogStyle const *style, 
+cb_size_elements (unsigned i, GOStyle const *style, 
 		  char const *name, GogLegendView *glv)
 {
 	GogView *view = GOG_VIEW (glv);
@@ -271,7 +274,7 @@ cb_size_elements (unsigned i, GogStyle const *style,
 		glv->element_width = aabr.w;
 	if (glv->element_height < aabr.h)
 		glv->element_height = aabr.h;
-	if (!glv->uses_lines && (style->interesting_fields & GOG_STYLE_LINE)) 
+	if (!glv->uses_lines && (style->interesting_fields & GO_STYLE_LINE)) 
 		glv->uses_lines = TRUE;
 }
 
@@ -284,7 +287,7 @@ gog_legend_view_size_request (GogView *v,
 	GogLegendView *glv = GOG_LEGEND_VIEW (v);
 	GogLegend *l = GOG_LEGEND (v->model);
 	GogViewRequisition child_req, residual, frame_req;
-	GogStyle *style;
+	GOStyle *style;
 	double available_space, element_size;
 	unsigned num_elements;
 
@@ -314,7 +317,7 @@ gog_legend_view_size_request (GogView *v,
 		return;
 	}
 
-	style = gog_styled_object_get_style (GOG_STYLED_OBJECT (l));
+	style = go_styled_object_get_style (GO_STYLED_OBJECT (l));
 	gog_renderer_push_style (v->renderer, style);
 	
 	glv->font_size = pango_font_description_get_size (style->font.font->desc) / PANGO_SCALE;
@@ -370,36 +373,43 @@ typedef struct {
 } SwatchScaleClosure;
 
 static void
-cb_swatch_scale (unsigned i, GogStyle const *style, char const *name,
+cb_swatch_scale (unsigned i, GOStyle const *style, char const *name,
 		 SwatchScaleClosure *data)
 {
+	GOStyleLine const *line = NULL;
 	double size;
 	double maximum, scale;
-       
+
 	size = go_marker_get_size (style->marker.mark);
 	if (data->size_max < size)
 		data->size_max = size;
 	if (data->size_min > size)
 		data->size_min = size;
 
-	if (style->interesting_fields & GOG_STYLE_LINE &&
-	    style->line.width > data->hairline_width) {
-		if (style->line.dash_type != GO_LINE_NONE && style->line.dash_type != GO_LINE_SOLID)
-			maximum = data->line_length / (GLV_SAMPLE_DASH_LENGTH 
-						       * go_line_dash_get_length (style->line.dash_type));
-		else
-			maximum = style->line.width;
+	if (style->interesting_fields & GO_STYLE_LINE)
+		line = &style->line;
+	else if (style->interesting_fields & GO_STYLE_OUTLINE)
+		line = &style->outline;
 
-		if (maximum > data->line_width_max)
-			maximum = data->line_width_max;
+	if (line == NULL ||
+	    line->width <= data->hairline_width)
+		return;
 
-		if (maximum > data->hairline_width) 
-			scale = (maximum - data->hairline_width) / (style->line.width - data->hairline_width);
-		else 
-			scale = 0;
-		if (data->line_scale > scale)
-			data->line_scale = scale;
-	}
+	if (line->dash_type != GO_LINE_NONE && line->dash_type != GO_LINE_SOLID)
+		maximum = data->line_length / (GLV_SAMPLE_DASH_LENGTH
+					       * go_line_dash_get_length (line->dash_type));
+	else
+		maximum = line->width;
+
+	if (maximum > data->line_width_max)
+		maximum = data->line_width_max;
+
+	if (maximum > data->hairline_width)
+		scale = (maximum - data->hairline_width) / (line->width - data->hairline_width);
+	else
+		scale = 0;
+	if (data->line_scale > scale)
+		data->line_scale = scale;
 }
 
 typedef struct {
@@ -409,22 +419,22 @@ typedef struct {
 	double element_step_x, element_step_y;
 	double block_step_x, block_step_y;
 	GogViewAllocation swatch;
-	ArtVpath line_path[3];
 	double swatch_scale_a, swatch_scale_b;
 	double line_scale_a, line_scale_b;
 	double hairline_width;
 } RenderClosure;
 
 static void
-cb_render_elements (unsigned index, GogStyle const *base_style, char const *name,
+cb_render_elements (unsigned index, GOStyle const *base_style, char const *name,
 		    RenderClosure *data)
 {
 	GogView const *view = data->view;
 	GogLegendView *glv = GOG_LEGEND_VIEW (view);
 	GogRenderer *renderer = view->renderer;
-	GogStyle *style = NULL;
+	GOStyle *style = NULL;
 	GogViewAllocation pos, rectangle;
-	double half_width;
+	double half_width, y;
+	GOPath *line_path;
 
 	if (data->count > 0) {
 		if ((data->count % glv->element_per_blocks) != 0) {
@@ -436,10 +446,11 @@ cb_render_elements (unsigned index, GogStyle const *base_style, char const *name
 		}
 	}
 	data->count++;
-	
-	if (base_style->interesting_fields & GOG_STYLE_LINE) { /* line and marker */
-		style = gog_style_dup (base_style);
-		go_marker_set_size (style->marker.mark, 
+
+	if (base_style->interesting_fields & GO_STYLE_LINE) { /* line and marker */
+		style = go_style_dup (base_style);
+		g_return_if_fail (style != NULL);
+		go_marker_set_size (style->marker.mark,
 				    go_marker_get_size (style->marker.mark) *
 				    data->swatch_scale_a + data->swatch_scale_b);
 		if (style->line.width > data->hairline_width)
@@ -447,24 +458,33 @@ cb_render_elements (unsigned index, GogStyle const *base_style, char const *name
 
 		gog_renderer_push_style (renderer, style);
 		half_width = 0.5 * gog_renderer_line_size (renderer, style->line.width);
-		data->line_path[0].x = data->x + half_width;
-		data->line_path[1].x = data->x + data->swatch.w * GLV_LINE_LENGTH_EM - half_width;
-		data->line_path[0].y = 
-		data->line_path[1].y = data->y + glv->element_height / 2.;
-		gog_renderer_draw_path (renderer, data->line_path);
-		gog_renderer_draw_marker (renderer, data->x + data->swatch.w  * GLV_LINE_LENGTH_EM * 0.5, 
-					  data->line_path[0].y);
+		line_path = go_path_new ();
+		y = data->y + glv->element_height / 2.;
+		go_path_move_to (line_path, data->x + half_width, y);
+		go_path_line_to (line_path, data->x + data->swatch.w * GLV_LINE_LENGTH_EM - half_width, y);
+		if (style->interesting_fields & GO_STYLE_FILL) {
+			rectangle.x = data->x - half_width;
+			rectangle.y = y;
+			rectangle.w = data->swatch.w * GLV_LINE_LENGTH_EM + 2.0 * half_width;
+			rectangle.h = glv->element_height / 2.0;
+			gog_renderer_fill_rectangle (renderer, &rectangle);
+		}
+		gog_renderer_stroke_serie (renderer, line_path);
+		go_path_free (line_path);
+		gog_renderer_draw_marker (renderer, data->x + data->swatch.w  * GLV_LINE_LENGTH_EM * 0.5, y);
 	} else {					/* area swatch */
-		style = gog_style_dup (base_style);
-		style->outline.width = 0; 
-		style->outline.color = RGBA_BLACK;
+		style = go_style_dup (base_style);
+		if (style->outline.width > data->hairline_width)
+			style->outline.width =
+				0.5 * (data->hairline_width + style->outline.width) * data->line_scale_a +
+				data->line_scale_b;
 
 		rectangle = data->swatch;
 		rectangle.x += data->x;
 		rectangle.y += data->y;
 
 		gog_renderer_push_style (renderer, style);
-		gog_renderer_draw_sharp_rectangle (renderer, &rectangle);
+		gog_renderer_draw_rectangle (renderer, &rectangle);
 	}
 	gog_renderer_pop_style (renderer);
 
@@ -482,7 +502,7 @@ gog_legend_view_render (GogView *v, GogViewAllocation const *bbox)
 {
 	GogLegendView *glv = GOG_LEGEND_VIEW (v);
 	GogLegend *l = GOG_LEGEND (v->model);
-	GogStyle *style = gog_styled_object_get_style (GOG_STYLED_OBJECT (l));
+	GOStyle *style = go_styled_object_get_style (GO_STYLED_OBJECT (l));
 	RenderClosure data;
 	SwatchScaleClosure swatch_data;
 	double swatch_size_min;
@@ -490,15 +510,15 @@ gog_legend_view_render (GogView *v, GogViewAllocation const *bbox)
 	double hairline_width;
 
 	(lview_parent_klass->render) (v, bbox);
-	
+
 	if (glv->element_per_blocks < 1)
 		return;
-	
-	gog_renderer_push_clip (v->renderer, 
-				gog_renderer_get_rectangle_vpath (&v->residual));
+
+	gog_renderer_push_clip_rectangle (v->renderer, v->residual.x, v->residual.y,
+					  v->residual.w, v->residual.h);
 
 	gog_renderer_push_style (v->renderer, style);
-	
+
 	hairline_width = gog_renderer_get_hairline_width_pts (v->renderer);
 	swatch_data.size_max = 0.0;
 	swatch_data.size_min = glv->font_size;
@@ -506,7 +526,7 @@ gog_legend_view_render (GogView *v, GogViewAllocation const *bbox)
 	swatch_data.line_width_max = GLV_LINE_WIDTH_MAX_DEFAULT_EM * glv->font_size;
 	swatch_data.line_length = GLV_LINE_LENGTH_EM * glv->font_size;
 	swatch_data.hairline_width = hairline_width;
-	
+
 	gog_chart_foreach_elem (GOG_CHART (v->model->parent), TRUE,
 		(GogEnumFunc) cb_swatch_scale, &swatch_data);
 
@@ -530,11 +550,11 @@ gog_legend_view_render (GogView *v, GogViewAllocation const *bbox)
 
 	data.hairline_width = hairline_width;
 
-	if (glv->uses_lines) {
+/*	if (glv->uses_lines) {
 		data.line_path[0].code = ART_MOVETO;
 		data.line_path[1].code = ART_LINETO;
 		data.line_path[2].code = ART_END;
-	}
+	}*/
 	
 	data.count = 0;
 	data.view = v;
@@ -573,4 +593,4 @@ gog_legend_view_class_init (GogLegendViewClass *gview_klass)
 
 static GSF_CLASS (GogLegendView, gog_legend_view,
 		  gog_legend_view_class_init, NULL,
-		  GOG_OUTLINED_VIEW_TYPE)
+		  GOG_TYPE_OUTLINED_VIEW)
