@@ -20,22 +20,11 @@
  */
 
 #include <goffice/goffice-config.h>
-#include <goffice/graph/gog-series-impl.h>
-#include <goffice/graph/gog-data-allocator.h>
-#include <goffice/graph/gog-plot-impl.h>
-#include <goffice/graph/gog-theme.h>
-#include <goffice/graph/gog-style.h>
-#include <goffice/graph/gog-error-bar.h>
-#include <goffice/data/go-data.h>
-#include <goffice/utils/go-persist.h>
+#include <goffice/goffice.h>
 
 #include <gsf/gsf-impl-utils.h>
 #include <glib/gi18n-lib.h>
 
-#ifdef GOFFICE_WITH_GTK
-#include <goffice/gtk/goffice-gtk.h>
-#endif
-
 #include <string.h>
 
 /* Keep in sync with GogSeriesFillType enum */
@@ -80,8 +69,8 @@ static void
 gog_series_element_set_index (GogSeriesElement *gse, int ind)
 {
 	gse->index = ind;
-	gog_styled_object_apply_theme (&gse->base, gse->base.style);
-	gog_styled_object_style_changed (&gse->base);
+	go_styled_object_apply_theme (GO_STYLED_OBJECT (gse), gse->base.style);
+	go_styled_object_style_changed (GO_STYLED_OBJECT (gse));
 }
 
 static void
@@ -145,7 +134,7 @@ cb_index_changed (GtkSpinButton *spin_button, GogSeriesElement *element)
 
 static void
 gog_series_element_populate_editor (GogObject *gobj,
-				    GogEditor *editor,
+				    GOEditor *editor,
 			   GogDataAllocator *dalloc,
 			   GOCmdContext *cc)
 {
@@ -178,21 +167,21 @@ gog_series_element_populate_editor (GogObject *gobj,
 	gtk_widget_show_all (vbox);
 
 	if (gse_vbox == NULL)
-		gog_editor_add_page (editor, vbox, _("Settings"));
+		go_editor_add_page (editor, vbox, _("Settings"));
 
-	gog_editor_set_store_page (editor, &series_element_pref_page);
+	go_editor_set_store_page (editor, &series_element_pref_page);
 }
 #endif
 
 static void
-gog_series_element_init_style (GogStyledObject *gso, GogStyle *style)
+gog_series_element_init_style (GogStyledObject *gso, GOStyle *style)
 {
 	GogSeries const *series = GOG_SERIES (GOG_OBJECT (gso)->parent);
-	GogStyle *parent_style;
+	GOStyle *parent_style;
 
 	g_return_if_fail (series != NULL);
 
-	parent_style = gog_styled_object_get_style (GOG_STYLED_OBJECT (series));
+	parent_style = go_styled_object_get_style (GO_STYLED_OBJECT (series));
 	style->interesting_fields = parent_style->interesting_fields;
 	gog_theme_fillin_style (gog_object_get_theme (GOG_OBJECT (gso)),
 		style, GOG_OBJECT (gso), GOG_SERIES_ELEMENT (gso)->index, FALSE);
@@ -226,7 +215,7 @@ gog_series_element_class_init (GogSeriesElementClass *klass)
 
 GSF_CLASS (GogSeriesElement, gog_series_element,
 	   gog_series_element_class_init, NULL /*gog_series_element_init*/,
-	   GOG_STYLED_OBJECT_TYPE)
+	   GOG_TYPE_STYLED_OBJECT)
 
 /*****************************************************************************/
 
@@ -277,7 +266,7 @@ role_series_element_allocate (GogObject *series)
 	GogObject *gse;
 
 	if (type == 0)
-		type = GOG_SERIES_ELEMENT_TYPE;
+		type = GOG_TYPE_SERIES_ELEMENT;
 
 	gse = g_object_new (type, NULL);
 	if (gse != NULL)
@@ -290,8 +279,8 @@ static void
 role_series_element_post_add (GogObject *parent, GogObject *child)
 {
 	GogSeries *series = GOG_SERIES (parent);
-	gog_styled_object_set_style (GOG_STYLED_OBJECT (child),
-		gog_styled_object_get_style (GOG_STYLED_OBJECT (parent)));
+	go_styled_object_set_style (GO_STYLED_OBJECT (child),
+		go_styled_object_get_style (GO_STYLED_OBJECT (parent)));
 	series->overrides = g_list_insert_sorted (series->overrides, child,
 		(GCompareFunc) element_compare);
 }
@@ -384,9 +373,10 @@ gog_series_get_property (GObject *obj, guint param_id,
 
 #ifdef GOFFICE_WITH_GTK
 static unsigned
-make_dim_editor (GtkTable *table, unsigned row, GtkWidget *editor,
+make_dim_editor (GtkTable *table, unsigned row, GogDataEditor *deditor,
 		 char const *name, GogSeriesPriority priority, gboolean is_shared)
 {
+	GtkWidget *editor = GTK_WIDGET (deditor);
 	char *txt = g_strdup_printf (
 		((priority != GOG_SERIES_REQUIRED) ? "(_%s):" : "_%s:"), _(name));
 	GtkWidget *label = gtk_label_new_with_mnemonic (txt);
@@ -446,7 +436,7 @@ cb_fill_type_changed (GtkComboBox *combo, GObject *obj)
 
 static void
 gog_series_populate_editor (GogObject *gobj,
-			    GogEditor *editor,
+			    GOEditor *editor,
 		   GogDataAllocator *dalloc,
 		   GOCmdContext *cc)
 {
@@ -521,16 +511,16 @@ gog_series_populate_editor (GogObject *gobj,
 		0, 2, row, row+1, GTK_FILL, 0, 0, 0);
 	gtk_widget_show_all (GTK_WIDGET (table));
 
-	gog_editor_add_page (editor, GTK_WIDGET (table), _("Data"));
+	go_editor_add_page (editor, GTK_WIDGET (table), _("Data"));
 
 	(GOG_OBJECT_CLASS(series_parent_klass)->populate_editor) (gobj, editor, dalloc, cc);
 
-	box = gog_editor_get_registered_widget (editor, "line_box");
+	box = go_editor_get_registered_widget (editor, "line_box");
 	if (series_class->has_interpolation && box != NULL) {
 		GladeXML *gui;
 		GtkWidget *widget;
 
-		gui = go_libglade_new ("gog-series-prefs.glade", "interpolation_prefs", GETTEXT_PACKAGE, cc);
+		gui = go_glade_new ("gog-series-prefs.glade", "interpolation_prefs", GETTEXT_PACKAGE, cc);
 		if (gui != NULL) {
 			int i;
 			GogAxisSet set = gog_plot_axis_set_pref (gog_series_get_plot (series));
@@ -579,12 +569,12 @@ gog_series_populate_editor (GogObject *gobj,
 		}
 	}
 
-	box = gog_editor_get_registered_widget (editor, "fill_extension_box");
+	box = go_editor_get_registered_widget (editor, "fill_extension_box");
 	if (series_class->has_fill_type && box != NULL) {
 		GladeXML *gui;
 		GtkWidget *widget;
 
-		gui = go_libglade_new ("gog-series-prefs.glade", "fill_type_prefs", GETTEXT_PACKAGE, cc);
+		gui = go_glade_new ("gog-series-prefs.glade", "fill_type_prefs", GETTEXT_PACKAGE, cc);
 		if (gui != NULL) {
 			widget = glade_xml_get_widget (gui, "fill_type_combo");
 			gog_series_populate_fill_type_combo (GOG_SERIES (series), GTK_COMBO_BOX (widget));
@@ -601,7 +591,7 @@ gog_series_populate_editor (GogObject *gobj,
 		}
 	}
 
-	gog_editor_set_store_page (editor, &series_pref_page);
+	go_editor_set_store_page (editor, &series_pref_page);
 }
 #endif
 
@@ -613,7 +603,7 @@ gog_series_update (GogObject *obj)
 }
 
 static void
-gog_series_init_style (GogStyledObject *gso, GogStyle *style)
+gog_series_init_style (GogStyledObject *gso, GOStyle *style)
 {
 	GogSeries const *series = (GogSeries const *)gso;
 	style->interesting_fields = series->plot->desc.series.style_fields;
@@ -681,7 +671,7 @@ gog_series_class_init (GogSeriesClass *klass)
 			_("Interpolation"),
 			_("Type of line interpolation"),
 			"linear",
-			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT | GOG_PARAM_FORCE_SAVE));
 	g_object_class_install_property (gobject_klass, SERIES_PROP_INTERPOLATION_SKIP_INVALID,
 		g_param_spec_boolean ("interpolation-skip-invalid", 
 			_("Interpolation skip invalid"),
@@ -745,14 +735,13 @@ gog_series_dataset_set_dim (GogDataset *set, int dim_i,
 	GogSeries *series = GOG_SERIES (set);
 	GogGraph *graph = gog_object_get_graph (GOG_OBJECT (series));
 
-	g_return_if_fail (IS_GOG_PLOT (series->plot));
+	g_return_if_fail (GOG_IS_PLOT (series->plot));
 	g_return_if_fail (dim_i >= -1);
 
 	if (dim_i < 0) {
 		char *name = NULL;
 		if (NULL != series->values[-1].data)
-			name = g_strdup (go_data_scalar_get_str (
-				GO_DATA_SCALAR (series->values[-1].data)));
+			name = go_data_get_scalar_string (series->values[-1].data);
 		gog_object_set_name (GOG_OBJECT (series), name, err);
 		return;
 	}
@@ -803,9 +792,9 @@ gog_series_dataset_dim_changed (GogDataset *set, int dim_i)
 		gog_object_request_update (GOG_OBJECT (set));
 	} else {
 		GOData *name_src = series->values[-1].data;
-		char const *name = (name_src != NULL)
-			? go_data_scalar_get_str (GO_DATA_SCALAR (name_src)) : NULL;
-		gog_object_set_name (GOG_OBJECT (set), g_strdup (name), NULL);
+		char *name = (name_src != NULL)
+			? go_data_get_scalar_string (name_src) : NULL;
+		gog_object_set_name (GOG_OBJECT (set), name, NULL);
 	}
 }
 
@@ -820,8 +809,8 @@ gog_series_dataset_init (GogDatasetClass *iface)
 
 GSF_CLASS_FULL (GogSeries, gog_series,
 		NULL, NULL, gog_series_class_init, NULL,
-		gog_series_init, GOG_STYLED_OBJECT_TYPE, 0,
-		GSF_INTERFACE (gog_series_dataset_init, GOG_DATASET_TYPE))
+		gog_series_init, GOG_TYPE_STYLED_OBJECT, 0,
+		GSF_INTERFACE (gog_series_dataset_init, GOG_TYPE_DATASET))
 
 /**
  * gog_series_get_plot :
@@ -832,7 +821,7 @@ GSF_CLASS_FULL (GogSeries, gog_series,
 GogPlot *
 gog_series_get_plot (GogSeries const *series)
 {
-	g_return_val_if_fail (IS_GOG_SERIES (series), NULL);
+	g_return_val_if_fail (GOG_IS_SERIES (series), NULL);
 	return series->plot;
 }
 
@@ -845,7 +834,7 @@ gog_series_get_plot (GogSeries const *series)
 gboolean
 gog_series_is_valid (GogSeries const *series)
 {
-	g_return_val_if_fail (IS_GOG_SERIES (series), FALSE);
+	g_return_val_if_fail (GOG_IS_SERIES (series), FALSE);
 	return series->is_valid;
 }
 
@@ -863,8 +852,8 @@ gog_series_check_validity (GogSeries *series)
 	unsigned i;
 	GogSeriesDesc const *desc;
 
-	g_return_if_fail (IS_GOG_SERIES (series));
-	g_return_if_fail (IS_GOG_PLOT (series->plot));
+	g_return_if_fail (GOG_IS_SERIES (series));
+	g_return_if_fail (GOG_IS_PLOT (series->plot));
 
 	desc = &series->plot->desc.series;
 	for (i = series->plot->desc.series.num_dim; i-- > 0; )
@@ -885,7 +874,7 @@ gog_series_check_validity (GogSeries *series)
 gboolean
 gog_series_has_legend (GogSeries const *series)
 {
-	g_return_val_if_fail (IS_GOG_SERIES (series), FALSE);
+	g_return_val_if_fail (GOG_IS_SERIES (series), FALSE);
 	return series->has_legend;
 }
 
@@ -904,7 +893,7 @@ gog_series_has_legend (GogSeries const *series)
 void
 gog_series_set_index (GogSeries *series, int ind, gboolean is_manual)
 {
-	g_return_if_fail (IS_GOG_SERIES (series));
+	g_return_if_fail (GOG_IS_SERIES (series));
 
 	if (ind < 0) {
 		if (series->manual_index && series->plot != NULL)
@@ -919,8 +908,8 @@ gog_series_set_index (GogSeries *series, int ind, gboolean is_manual)
 		return;
 
 	series->index = ind;
-	gog_styled_object_apply_theme (&series->base, series->base.style);
-	gog_styled_object_style_changed (GOG_STYLED_OBJECT (series));
+	go_styled_object_apply_theme (GO_STYLED_OBJECT (series), series->base.style);
+	go_styled_object_style_changed (GO_STYLED_OBJECT (series));
 }
 
 /**
@@ -932,11 +921,12 @@ gog_series_set_index (GogSeries *series, int ind, gboolean is_manual)
  *
  * return value: a #GODataScalar, without added reference.
  **/
-GODataScalar *
+GOData *
 gog_series_get_name (GogSeries const *series)
 {
-	g_return_val_if_fail (IS_GOG_SERIES (series), NULL);
-	return GO_DATA_SCALAR (series->values[-1].data);
+	g_return_val_if_fail (GOG_IS_SERIES (series), NULL);
+
+	return series->values[-1].data;
 }
 
 /**
@@ -993,7 +983,7 @@ gog_series_get_valid_element_index (GogSeries const *series, int old_index, int
 	int index;
 	GList *ptr;
 
-	g_return_val_if_fail (IS_GOG_SERIES (series), -1);
+	g_return_val_if_fail (GOG_IS_SERIES (series), -1);
 
 	if ((desired_index >= (int) series->num_elements) ||
 	    (desired_index < 0))
@@ -1029,7 +1019,7 @@ gog_series_get_element (GogSeries const *series, int index)
 	GList *ptr;
 	GogSeriesElement *element;
 
-	g_return_val_if_fail (IS_GOG_SERIES (series), NULL);
+	g_return_val_if_fail (GOG_IS_SERIES (series), NULL);
 
 	for (ptr = series->overrides; ptr != NULL; ptr = ptr->next) {
 		element = GOG_SERIES_ELEMENT (ptr->data);
@@ -1043,7 +1033,7 @@ gog_series_get_element (GogSeries const *series, int index)
 static unsigned int
 gog_series_get_data (GogSeries const *series, int *indices, double **data, int n_vectors)
 {
-	GODataVector *vector;
+	GOData *vector;
 	int i, n_points = 0, vector_n_points;
 	int first, last;
 	int index;
@@ -1057,9 +1047,9 @@ gog_series_get_data (GogSeries const *series, int *indices, double **data, int n
 	for (i = 0; i < n_vectors; i++) {
 		index = indices != NULL ? indices[i] : i;
 		if (index >= first && index <= last &&
-		    (vector = GO_DATA_VECTOR (series->values[index].data)) != NULL) {
-			data[i] = go_data_vector_get_values (vector);
-			vector_n_points = go_data_vector_get_len (vector);
+		    (vector = series->values[index].data) != NULL) {
+			data[i] = go_data_get_values (vector);
+			vector_n_points = go_data_get_vector_size (vector);
 			if (!is_set) {
 				is_set = TRUE;
 				n_points = vector_n_points;
@@ -1126,7 +1116,7 @@ gog_series_get_xyz_data (GogSeries const  *series,
 GogSeriesFillType
 gog_series_get_fill_type (GogSeries const *series)
 {
-	g_return_val_if_fail (IS_GOG_SERIES (series), GOG_SERIES_FILL_TYPE_INVALID);
+	g_return_val_if_fail (GOG_IS_SERIES (series), GOG_SERIES_FILL_TYPE_INVALID);
 
 	return series->fill_type;
 }
@@ -1136,7 +1126,7 @@ gog_series_set_fill_type (GogSeries *series, GogSeriesFillType fill_type)
 {
 	GogSeriesClass *series_klass;
 
-	g_return_if_fail (IS_GOG_SERIES (series));
+	g_return_if_fail (GOG_IS_SERIES (series));
 	if (series->fill_type == fill_type)
 		return;
 	g_return_if_fail (fill_type >= 0 && fill_type < GOG_SERIES_FILL_TYPE_INVALID);
@@ -1156,7 +1146,7 @@ gog_series_populate_fill_type_combo (GogSeries const *series, GtkComboBox *combo
 	GogSeriesFillType fill_type;
 	unsigned int i;
 
-	g_return_if_fail (IS_GOG_SERIES (series));
+	g_return_if_fail (GOG_IS_SERIES (series));
 	series_klass = GOG_SERIES_GET_CLASS (series);
 	g_return_if_fail (series_klass->valid_fill_type_list != NULL);
 
@@ -1176,7 +1166,7 @@ gog_series_get_fill_type_from_combo (GogSeries const *series, GtkComboBox *combo
 {
 	GogSeriesClass *series_klass;
 
-	g_return_val_if_fail (IS_GOG_SERIES (series), GOG_SERIES_FILL_TYPE_INVALID);
+	g_return_val_if_fail (GOG_IS_SERIES (series), GOG_SERIES_FILL_TYPE_INVALID);
 	series_klass = GOG_SERIES_GET_CLASS (series);
 	g_return_val_if_fail (series_klass->valid_fill_type_list != NULL, GOG_SERIES_FILL_TYPE_INVALID);
 
@@ -1189,7 +1179,7 @@ gog_series_get_interpolation_params (GogSeries const *series)
 {
 	GogSeriesClass *series_klass;
 
-	g_return_val_if_fail (IS_GOG_SERIES (series), NULL);
+	g_return_val_if_fail (GOG_IS_SERIES (series), NULL);
 	series_klass = GOG_SERIES_GET_CLASS (series);
 	return (series_klass->get_interpolation_params)?
 			series_klass->get_interpolation_params (series):
