@@ -25,13 +25,6 @@
 #include "go-color-palette.h"
 #include "goffice-gtk.h"
 
-#include <gtk/gtkaction.h>
-#include <gtk/gtktoolitem.h>
-#include <gtk/gtkicontheme.h>
-#include <gtk/gtkiconfactory.h>
-#include <gtk/gtkimagemenuitem.h>
-#include <gtk/gtkimage.h>
-#include <gtk/gtktoolbar.h>
 #include <gsf/gsf-impl-utils.h>
 
 #include <glib/gi18n-lib.h>
@@ -42,11 +35,13 @@ typedef struct {
 } GOToolComboColor;
 typedef GtkToolItemClass GOToolComboColorClass;
 
-#define GO_TOOL_COMBO_COLOR_TYPE	(go_tool_combo_color_get_type ())
-#define GO_TOOL_COMBO_COLOR(o)		(G_TYPE_CHECK_INSTANCE_CAST (o, GO_TOOL_COMBO_COLOR_TYPE, GOToolComboColor))
-#define IS_GO_TOOL_COMBO_COLOR(o)	(G_TYPE_CHECK_INSTANCE_TYPE (o, GO_TOOL_COMBO_COLOR_TYPE))
+#define GO_TYPE_TOOL_COMBO_COLOR	(go_tool_combo_color_get_type ())
+#define GO_TOOL_COMBO_COLOR(o)		(G_TYPE_CHECK_INSTANCE_CAST (o, GO_TYPE_TOOL_COMBO_COLOR, GOToolComboColor))
+#define GO_IS_TOOL_COMBO_COLOR(o)	(G_TYPE_CHECK_INSTANCE_TYPE (o, GO_TYPE_TOOL_COMBO_COLOR))
 
 static GType go_tool_combo_color_get_type (void);
+
+#ifndef HAVE_GTK_TOOL_ITEM_SET_TOOLTIP_TEXT
 static gboolean
 go_tool_combo_color_set_tooltip (GtkToolItem *tool_item, GtkTooltips *tooltips,
 				 char const *tip_text,
@@ -57,10 +52,14 @@ go_tool_combo_color_set_tooltip (GtkToolItem *tool_item, GtkTooltips *tooltips,
 				  tip_text, tip_private);
 	return TRUE;
 }
+#endif
+
 static void
 go_tool_combo_color_class_init (GtkToolItemClass *tool_item_class)
 {
+#ifndef HAVE_GTK_TOOL_ITEM_SET_TOOLTIP_TEXT
 	tool_item_class->set_tooltip = go_tool_combo_color_set_tooltip;
+#endif
 }
 
 static GdkPixbuf *
@@ -76,7 +75,7 @@ make_icon (GtkAction *a, GtkWidget *tool)
 	g_object_get (a, "stock-id", &stock_id, NULL);
 	if (stock_id == NULL)
 		return NULL;
-	if (IS_GO_TOOL_COMBO_COLOR (tool)) {
+	if (GO_IS_TOOL_COMBO_COLOR (tool)) {
 		if (tool->parent)
 			size = gtk_toolbar_get_icon_size (GTK_TOOLBAR (tool->parent));
 		else
@@ -105,7 +104,7 @@ static GSF_CLASS (GOToolComboColor, go_tool_combo_color,
 struct _GOActionComboColor {
 	GtkAction	 base;
 	GOColorGroup 	*color_group;
-	char const 	*default_val_label;
+	char		*default_val_label;
 	GOColor		 default_val, current_color;
 };
 typedef struct {
@@ -171,7 +170,7 @@ static GtkWidget *
 go_action_combo_color_create_tool_item (GtkAction *a)
 {
 	GOActionComboColor *caction = (GOActionComboColor *)a;
-	GOToolComboColor *tool = g_object_new (GO_TOOL_COMBO_COLOR_TYPE, NULL);
+	GOToolComboColor *tool = g_object_new (GO_TYPE_TOOL_COMBO_COLOR, NULL);
 	char *title;
 
 	/* FIXME: We probably should re-do this when tool changes screen or
@@ -181,6 +180,7 @@ go_action_combo_color_create_tool_item (GtkAction *a)
 	tool->combo = (GOComboColor *)go_combo_color_new (icon,
 		caction->default_val_label, caction->default_val,
 		caction->color_group);
+	if (icon) g_object_unref (icon);
 
 	go_combo_color_set_instant_apply (GO_COMBO_COLOR (tool->combo), TRUE);
 	go_combo_box_set_relief (GO_COMBO_BOX (tool->combo), GTK_RELIEF_NONE);
@@ -228,6 +228,7 @@ go_action_combo_color_finalize (GObject *obj)
 	GOActionComboColor *color = (GOActionComboColor *)obj;
 	if (color->color_group != NULL)
 		g_object_unref (color->color_group);
+	g_free (color->default_val_label);
 
 	combo_color_parent->finalize (obj);
 }
@@ -297,6 +298,6 @@ go_action_combo_color_set_color (GOActionComboColor *a, GOColor color)
 
 	a->current_color = color;
 	for ( ; ptr != NULL ; ptr = ptr->next)
-		if (IS_GO_TOOL_COMBO_COLOR (ptr->data))
+		if (GO_IS_TOOL_COMBO_COLOR (ptr->data))
 			go_combo_color_set_color (GO_TOOL_COMBO_COLOR (ptr->data)->combo, color);
 }
