@@ -27,7 +27,8 @@
  */
 
 #include <goffice/goffice-config.h>
-#include "go-color-group.h"
+#include <goffice/goffice.h>
+
 #include <gsf/gsf-impl-utils.h>
 #include <string.h>
 
