@@ -28,14 +28,11 @@
  */
 
 #include <goffice/goffice-config.h>
-#include "go-color-palette.h"
-#include <goffice/gtk/goffice-gtk.h>
+#include <goffice/goffice.h>
 #include <goffice/utils/go-marshalers.h>
 
-#include <goffice/utils/go-color.h>
-#include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
-#include <gdk/gdkcolor.h>
+#include <gdk/gdk.h>
 #include <glib/gi18n-lib.h>
 #include <gsf/gsf-impl-utils.h>
 
@@ -407,6 +404,7 @@ go_color_palette_set_group (GOColorPalette *p, GOColorGroup *cg)
 		p->group = NULL;
 	}
 	if (cg != NULL) {
+		g_object_ref (cg);
 		p->group = cg;
 		g_signal_connect_swapped (G_OBJECT (cg),
 			"history-changed",
@@ -516,7 +514,7 @@ go_color_palette_new (char const *no_color_label,
 	int const rows = 6;
 	GONamedColor const *color_names = default_color_set;
 
-	pal = g_object_new (GO_COLOR_PALETTE_TYPE, NULL);
+	pal = g_object_new (GO_TYPE_COLOR_PALETTE, NULL);
 
 	pal->default_set   = color_names;
 	pal->default_color = default_color;
