@@ -20,15 +20,8 @@
  */
 
 #include <goffice/goffice-config.h>
-#include "go-format-sel.h"
-
-#include "goffice/gtk/goffice-gtk.h"
-#include "goffice/gtk/go-combo-text.h"
-#include "goffice/utils/go-format.h"
-#include "goffice/utils/go-locale.h"
-#include "goffice/utils/go-color.h"
-#include "goffice/utils/go-marshalers.h"
-#include "goffice/utils/go-glib-extras.h"
+#include <goffice/goffice.h>
+#include <goffice/utils/go-marshalers.h>
 
 #include <gsf/gsf-impl-utils.h>
 #include <glib/gi18n-lib.h>
@@ -142,14 +135,8 @@ struct  _GOFormatSel {
 		gulong          entry_changed_id;
 		GOFormat const	*spec;
 		gint		current_type;
-		int		num_decimals;
-		int		negative_format;
-		int		currency_index;
-		gboolean        force_quoted;
-		gboolean	use_separator;
-		gboolean	use_markup;
-		int		exponent_step;
-		gboolean	simplify_mantissa;
+
+		GOFormatDetails details;
 	} format;
 };
 
@@ -171,192 +158,6 @@ static guint go_format_sel_signals [LAST_SIGNAL] = { 0 };
 
 static void format_entry_set_text (GOFormatSel *gfs, const gchar *text);
 
-static void
-generate_number (GString *dst,
-		 int num_decimals,
-		 gboolean thousands_sep,
-		 int symbol,
-		 gboolean force_quoted,
-		 int negative_fmt)
-{
-	gboolean precedes = go_format_currencies[symbol].precedes;
-	gboolean has_space = go_format_currencies[symbol].has_space;
-	const char *symstr = go_format_currencies[symbol].symbol;
-	gboolean extra_quotes = (force_quoted && symstr[0] != '"');
-
-	/* Currency */
-	if (symbol != 0 && precedes) {
-		if (extra_quotes) g_string_append_c (dst, '"');
-		g_string_append (dst, symstr);
-		if (extra_quotes) g_string_append_c (dst, '"');
-		if (has_space) g_string_append_c (dst, ' ');
-	}
-
-	if (thousands_sep)
-		g_string_append (dst, "#,##0");
-	else
-		g_string_append_c (dst, '0');
-
-	if (num_decimals > 0) {
-		g_string_append_c (dst, '.');
-		go_string_append_c_n (dst, '0', num_decimals);
-	}
-
-	/* Currency */
-	if (symbol != 0 && !precedes) {
-		if (has_space)
-			g_string_append_c (dst, ' ');
-		if (extra_quotes) g_string_append_c (dst, '"');
-		g_string_append (dst, symstr);
-		if (extra_quotes) g_string_append_c (dst, '"');
-	}
-
-	/* There are negatives */
-	if (negative_fmt > 0) {
-		size_t prelen = dst->len;
-
-		switch (negative_fmt) {
-		case 1 : g_string_append (dst, ";[Red]");
-			break;
-		case 2 : g_string_append (dst, "_);(");
-			break;
-		case 3 : g_string_append (dst, "_);[Red](");
-			break;
-		default :
-			g_assert_not_reached ();
-		};
-
-		g_string_append_len (dst, dst->str, prelen);
-
-		if (negative_fmt >= 2)
-			g_string_append_c (dst, ')');
-	}
-}
-
-static void
-generate_accounting (GString *dst,
-		     int num_decimals,
-		     int symbol)
-{
-	GString *num = g_string_new (NULL);
-	GString *sym = g_string_new (NULL);
-	GString *q = g_string_new (NULL);
-
-	gboolean precedes = go_format_currencies[symbol].precedes;
-	gboolean has_space = go_format_currencies[symbol].has_space;
-	const char *symstr = go_format_currencies[symbol].symbol;
-	const char *quote = symstr[0] != '[' ? "\"" : "";
-
-	generate_number (num, num_decimals, TRUE, 0, FALSE, 0);
-	go_string_append_c_n (q, '?', num_decimals);
-
-	if (precedes) {
-		g_string_append (sym, quote);
-		g_string_append (sym, symstr);
-		g_string_append (sym, quote);
-		g_string_append (sym, "* ");
-		if (has_space) g_string_append_c (sym, ' ');
-
-		g_string_append_printf
-			(dst,
-			 "_(%s%s_);_(%s(%s);_(%s\"-\"%s_);_(@_)",
-			 sym->str, num->str,
-			 sym->str, num->str,
-			 sym->str, q->str);
-	} else {
-		g_string_append (sym, "* ");
-		if (has_space) g_string_append_c (sym, ' ');
-		g_string_append (sym, quote);
-		g_string_append (sym, symstr);
-		g_string_append (sym, quote);
-
-		g_string_append_printf
-			(dst,
-			 "_(%s%s_);_((%s)%s;_(\"-\"%s%s_);_(@_)",
-			 num->str, sym->str,
-			 num->str, sym->str,
-			 q->str, sym->str);
-	}
-
-	g_string_free (num, TRUE);
-	g_string_free (q, TRUE);
-	g_string_free (sym, TRUE);
-}
-
-static void
-generate_scientific (GString *dst,
-		     int num_decimals,
-		     int exponent_step,
-		     gboolean use_markup,
-		     gboolean simplify_mantissa)
-{
-	go_string_append_c_n (dst, '#', MAX (0, exponent_step - 1));
-	if (simplify_mantissa)
-		g_string_append_c (dst, '#');
-	else
-		g_string_append_c (dst, '0');
-
-	if (num_decimals > 0) {
-		g_string_append_c (dst, '.');
-		go_string_append_c_n (dst, '0', num_decimals);
-	}
-
-	if (use_markup)
-		g_string_append (dst, "EE0");
-	else
-		g_string_append (dst, "E+00");
-}
-
-
-static char *
-generate_format (GOFormatSel *gfs, GOFormatFamily page)
-{
-	GString *fmt = g_string_new (NULL);
-
-	switch (page) {
-	case GO_FORMAT_GENERAL:
-	case GO_FORMAT_TEXT:
-		g_string_append (fmt, go_format_builtins[page][0]);
-		break;
-	case GO_FORMAT_NUMBER:
-		generate_number (fmt,
-				 gfs->format.num_decimals,
-				 gfs->format.use_separator,
-				 0,
-				 FALSE,
-				 gfs->format.negative_format);
-		break;
-	case GO_FORMAT_CURRENCY:
-		generate_number (fmt,
-				 gfs->format.num_decimals,
-				 gfs->format.use_separator,
-				 gfs->format.currency_index,
-				 gfs->format.force_quoted,
-				 gfs->format.negative_format);
-		break;
-	case GO_FORMAT_ACCOUNTING:
-		generate_accounting (fmt,
-				     gfs->format.num_decimals,
-				     gfs->format.currency_index);
-		break;
-	case GO_FORMAT_PERCENTAGE:
-		generate_number (fmt, gfs->format.num_decimals, FALSE, 0, FALSE, 0);
-		g_string_append_c (fmt, '%');
-		break;
-	case GO_FORMAT_SCIENTIFIC:
-		generate_scientific (fmt,
-				     gfs->format.num_decimals,
-				     gfs->format.exponent_step,
-				     gfs->format.use_markup,
-				     gfs->format.simplify_mantissa);
-		break;
-	default:
-		break;
-	}
-
-	return g_string_free (fmt, fmt->len == 0);
-}
-
 static char *
 generate_preview (GOFormatSel *gfs, GOColor *c)
 {
@@ -377,7 +178,11 @@ draw_format_preview (GOFormatSel *gfs, gboolean regen_format)
 	gsize len;
 
 	if (regen_format) {
-		char *fmt = generate_format (gfs, gfs->format.current_type);
+		GString *fmtstr = g_string_new (NULL);
+		char *fmt;
+
+		go_format_generate_str (fmtstr, &gfs->format.details);
+		fmt = g_string_free (fmtstr, fmtstr->len == 0);
 
 		if (fmt) {
 			char *lfmt = go_format_str_localize (fmt);
@@ -412,41 +217,56 @@ draw_format_preview (GOFormatSel *gfs, gboolean regen_format)
 static void
 fillin_negative_samples (GOFormatSel *gfs)
 {
-	GOFormatFamily const page = gfs->format.current_type;
 	int i;
-	GtkTreeIter  iter;
-	GtkTreePath *path;
+	GtkTreeIter iter;
 	gboolean more;
+	GOFormatDetails details = gfs->format.details;
+	double sample_value;
 	SETUP_LOCALE_SWITCH;
 
-	g_return_if_fail (page == GO_FORMAT_NUMBER || page == GO_FORMAT_CURRENCY);
-
 	START_LOCALE_SWITCH;
 
+	switch (gfs->format.current_type) {
+	case GO_FORMAT_DATE:
+		g_assert_not_reached ();
+		return;
+	case GO_FORMAT_PERCENTAGE:
+		sample_value = -0.123456;
+		break;
+	default:
+		sample_value = -3210.12345678;
+		break;
+	}
+
 	more = gtk_tree_model_get_iter_first (GTK_TREE_MODEL (gfs->format.negative_types.model), &iter);
 	for (i = 0 ; i < 4; i++) {
 		GString *fmtstr = g_string_new (NULL);
 		GOFormat *fmt;
 		char *buf;
 
-		generate_number (fmtstr,
-				 gfs->format.num_decimals,
-				 gfs->format.use_separator,
-				 page == GO_FORMAT_NUMBER ? 0 : gfs->format.currency_index,
-				 gfs->format.force_quoted,
-				 i);
+		details.negative_red = (i & 1) != 0;
+		details.negative_paren = (i & 2) != 0;
+
+		go_format_generate_str (fmtstr, &details);
 		fmt = go_format_new_from_XL (fmtstr->str);
 		g_string_free (fmtstr, TRUE);
-		buf = go_format_value (fmt, -3210.123456789);
+		buf = go_format_value (fmt, sample_value);
 		go_format_unref (fmt);
 
 		if (!more)
 			gtk_list_store_append (gfs->format.negative_types.model, &iter);
 		gtk_list_store_set (gfs->format.negative_types.model, &iter,
-				    0, i,
-				    1, buf,
-				    2, (i % 2) ? "red" : NULL,
+				    0, details.negative_red,
+				    1, details.negative_paren,
+				    2, buf,
+				    3, details.negative_red ? "red" : NULL,
 				    -1);
+		if (gfs->format.details.negative_red == details.negative_red &&
+		    gfs->format.details.negative_paren == details.negative_paren)
+			gtk_tree_selection_select_iter
+				(gfs->format.negative_types.selection,
+				 &iter);
+
 		if (more)
 			more = gtk_tree_model_iter_next (GTK_TREE_MODEL (gfs->format.negative_types.model),
 							 &iter);
@@ -454,22 +274,16 @@ fillin_negative_samples (GOFormatSel *gfs)
 		g_free (buf);
 	}
 
-	path = gtk_tree_path_new ();
-	gtk_tree_path_append_index (path, gfs->format.negative_format);
-	gtk_tree_selection_select_path (gfs->format.negative_types.selection, path);
-	gtk_tree_path_free (path);
-
 	END_LOCALE_SWITCH;
 }
 
 static void
 cb_decimals_changed (GtkSpinButton *spin, GOFormatSel *gfs)
 {
-	GOFormatFamily const page = gfs->format.current_type;
+	gfs->format.details.num_decimals =
+		gtk_spin_button_get_value_as_int (spin);
 
-	gfs->format.num_decimals = gtk_spin_button_get_value_as_int (spin);
-
-	if (page == GO_FORMAT_NUMBER || page == GO_FORMAT_CURRENCY)
+	if (GTK_WIDGET_VISIBLE (gfs->format.widget[F_NEGATIVE]))
 		fillin_negative_samples (gfs);
 
 	draw_format_preview (gfs, TRUE);
@@ -478,9 +292,11 @@ cb_decimals_changed (GtkSpinButton *spin, GOFormatSel *gfs)
 static void
 cb_separator_toggle (GtkObject *obj, GOFormatSel *gfs)
 {
-	gfs->format.use_separator =
+	gfs->format.details.thousands_sep =
 		gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (obj));
-	fillin_negative_samples (gfs);
+
+	if (GTK_WIDGET_VISIBLE (gfs->format.widget[F_NEGATIVE]))
+		fillin_negative_samples (gfs);
 
 	draw_format_preview (gfs, TRUE);
 }
@@ -489,9 +305,9 @@ static void
 cb_engineering_toggle (GtkObject *obj, GOFormatSel *gfs)
 {
 	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (obj)))
-		gfs->format.exponent_step = 3;
+		gfs->format.details.exponent_step = 3;
 	else
-		gfs->format.exponent_step = 1;
+		gfs->format.details.exponent_step = 1;
 
 	draw_format_preview (gfs, TRUE);
 }
@@ -499,10 +315,10 @@ cb_engineering_toggle (GtkObject *obj, GOFormatSel *gfs)
 static void
 cb_superscript_toggle (GtkObject *obj, GOFormatSel *gfs)
 {
-	gfs->format.use_markup =
+	gfs->format.details.use_markup =
 		gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (obj));
 	gtk_widget_set_sensitive (gfs->format.widget[F_SUPERSCRIPT_HIDE_1_BUTTON],
-				  gfs->format.use_markup);
+				  gfs->format.details.use_markup);
 
 	draw_format_preview (gfs, TRUE);
 }
@@ -510,7 +326,7 @@ cb_superscript_toggle (GtkObject *obj, GOFormatSel *gfs)
 static void
 cb_superscript_hide_1_toggle (GtkObject *obj, GOFormatSel *gfs)
 {
-	gfs->format.simplify_mantissa =
+	gfs->format.details.simplify_mantissa =
 		gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (obj));
 
 	draw_format_preview (gfs, TRUE);
@@ -636,6 +452,10 @@ fmt_dialog_enable_widgets (GOFormatSel *gfs, int page)
 			F_PERCENTAGE_EXPLANATION,
 			F_DECIMAL_LABEL,
 			F_DECIMAL_SPIN,
+			F_SEPARATOR,
+			F_NEGATIVE_LABEL,
+			F_NEGATIVE_SCROLL,
+			F_NEGATIVE,
 			F_MAX_WIDGET
 		},
 		/* Fraction */
@@ -712,7 +532,7 @@ stays:
 		g_free (lelem);
 	}
 
-	gfs->format.current_type = page;
+	gfs->format.details.family = gfs->format.current_type = page;
 	for (i = 0; (tmp = contents[page][i]) != F_MAX_WIDGET ; ++i) {
 		gboolean show_widget = TRUE;
 		GtkWidget *w = gfs->format.widget[tmp];
@@ -778,13 +598,13 @@ stays:
 
 		case F_DECIMAL_SPIN:
 			gtk_spin_button_set_value (GTK_SPIN_BUTTON (gfs->format.widget[F_DECIMAL_SPIN]),
-						   gfs->format.num_decimals);
+						   gfs->format.details.num_decimals);
 			break;
 
 		case F_SUPERSCRIPT_BUTTON:
 			if (gfs->show_format_with_markup) {
 				gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w),
-							      gfs->format.use_markup);
+							      gfs->format.details.use_markup);
 			} else 
 				show_widget = FALSE;
 			break;
@@ -793,8 +613,8 @@ stays:
 			if (gfs->show_format_with_markup) {
 				
 				gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w),
-							      gfs->format.simplify_mantissa);
-				gtk_widget_set_sensitive (w, gfs->format.use_markup);
+							      gfs->format.details.simplify_mantissa);
+				gtk_widget_set_sensitive (w, gfs->format.details.use_markup);
 			} else
 				show_widget = FALSE;
 			break;
@@ -802,12 +622,12 @@ stays:
 		case F_ENGINEERING_BUTTON:
 			gtk_toggle_button_set_active
 				(GTK_TOGGLE_BUTTON (gfs->format.widget[F_ENGINEERING_BUTTON]),
-				 gfs->format.exponent_step == 3);
+				 gfs->format.details.exponent_step == 3);
 			break;
 
 		case F_SEPARATOR:
 			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (gfs->format.widget[F_SEPARATOR]),
-						      gfs->format.use_separator);
+						      gfs->format.details.thousands_sep);
 			break;
 
 		default:
@@ -924,15 +744,17 @@ cb_format_currency_select (G_GNUC_UNUSED GtkWidget *ct,
 	if (!gfs->enable_edit || new_text == NULL || *new_text == '\0')
 		return FALSE;
 
-	for (i = 0; go_format_currencies[i].symbol != NULL ; ++i)
-		if (!strcmp (_(go_format_currencies[i].description), new_text)) {
-			gfs->format.currency_index = i;
+	for (i = 0; go_format_currencies[i].symbol != NULL ; ++i) {
+		GOFormatCurrency const *ci = go_format_currencies + i;
+		if (!strcmp (_(ci->description), new_text)) {
+			gfs->format.details.currency = ci;
 			break;
 		}
+	}
 
-	if (gfs->format.current_type == GO_FORMAT_NUMBER ||
-	    gfs->format.current_type == GO_FORMAT_CURRENCY)
+	if (GTK_WIDGET_VISIBLE (gfs->format.widget[F_NEGATIVE]))
 		fillin_negative_samples (gfs);
+
 	draw_format_preview (gfs, TRUE);
 
 	return TRUE;
@@ -942,14 +764,18 @@ static void
 cb_format_negative_form_selected (GtkTreeSelection *selection, GOFormatSel *gfs)
 {
 	GtkTreeIter iter;
-	int type;
+	int negative_red, negative_paren;
 
 	if (!gtk_tree_selection_get_selected (selection, NULL, &iter))
 		return;
 
 	gtk_tree_model_get (GTK_TREE_MODEL (gfs->format.negative_types.model),
-			    &iter, 0, &type, -1);
-	gfs->format.negative_format = type;
+			    &iter,
+			    0, &negative_red,
+			    1, &negative_paren,
+			    -1);
+	gfs->format.details.negative_red = negative_red;
+	gfs->format.details.negative_paren = negative_paren;
 	draw_format_preview (gfs, TRUE);
 }
 
@@ -992,170 +818,32 @@ set_format_category (GOFormatSel *gfs, int row)
 	gtk_tree_path_free (path);
 }
 
-/* Returns the index in go_format_currencies of the symbol in ptr */
-static int
-find_symbol (char const *ptr, gsize len, gboolean precedes)
-{
-	int i;
-	gboolean has_space;
-	gboolean quoted;
-
-	if (len <= 0)
-		return 0;
-
-	if (precedes) {
-		has_space = ptr[len - 1] == ' ';
-		if (has_space)
-			len--;
-	} else {
-		has_space = ptr[0] == ' ';
-		if (has_space)
-			len--, ptr++;
-	}
-
-	quoted = len > 2 && ptr[0] == '\"' && ptr[len - 1] == '\"';
-
-	for (i = 1; go_format_currencies[i].symbol; i++) {
-		const GOFormatCurrency *ci = go_format_currencies + i;
-
-		if (ci->precedes != precedes)
-			continue;
-
-		if (strncmp (ci->symbol, ptr, len) == 0) {
-			return i;
-		}
-
-		/* Allow quoting of things that aren't [$FOO] */
-		if (quoted && ci->symbol[0] != '[' &&
-		    strncmp (ci->symbol, ptr + 1, len - 2) == 0) {
-			return i;
-		}
-	}
-
-	return 0;
-}
-
 static GOFormatFamily
 study_format (GOFormatSel *gfs)
 {
 	const GOFormat *fmt = gfs->format.spec;
-	const char *str = go_format_as_XL (fmt);
-	char *newstr;
-	GOFormatFamily typ = go_format_get_family (fmt);
+	gboolean exact;
+	GOFormatDetails *details = &gfs->format.details;
 
-	gfs->format.num_decimals = 0;	
-	gfs->format.negative_format = 0;
-	gfs->format.currency_index = 0;
-	gfs->format.force_quoted = FALSE;
-	gfs->format.use_separator = FALSE;
-	gfs->format.use_markup = FALSE;
-	gfs->format.exponent_step = 1;
-	gfs->format.simplify_mantissa = FALSE;
+	go_format_get_details (fmt, details, &exact);
 
-	switch (typ) {
-	case GO_FORMAT_NUMBER:
-	case GO_FORMAT_CURRENCY:
-	case GO_FORMAT_ACCOUNTING:
-	case GO_FORMAT_PERCENTAGE:
-	case GO_FORMAT_SCIENTIFIC: {
-		/*
-		 * These guesses only have to be good enough to work on
-		 * the formats we generate ourselves.
-		 */
+	if (exact) {
+		/* Thing we do not have GUI for: */
+		if (details->family == GO_FORMAT_ACCOUNTING &&
+		    !details->thousands_sep)
+			exact = FALSE;
 
-		const char *dot = strchr (str, '.');
-
-		if (dot) {
-			while (dot[gfs->format.num_decimals + 1] == '0')
-				gfs->format.num_decimals++;
-		}
-
-		gfs->format.negative_format =
-			(strstr (str, ";[Red]") ? 1 : 0) +
-			(strstr (str, "_);") ? 2 : 0);
-
-		if (str[0] == '_' && str[1] == '(') {
-			const char *start = str + 2;
-			gboolean precedes = start[0] != '#';
-			gsize len = 0;
-
-			if (precedes) {
-				while (start[len] && start[len] != '*')
-					len++;
-			} else {
-				while (start[0] == '0' || start[0] == '.' ||
-				       start[0] == '#' || start[0] == ',')
-					start++;
-				if (start[0] == '*' && start[1])
-					start += 2;
-				while (start[len] && start[len] != '_')
-					len++;
-			}
-
-			gfs->format.currency_index =
-				find_symbol (start, len, precedes);
-			gfs->format.force_quoted = (start[0] == '"');
-			typ = GO_FORMAT_ACCOUNTING;
-		} else {
-			gboolean precedes = str[0] != '0' && str[0] != '#';
-			const char *start;
-			gsize len = 0;
-			int symbol;
-
-			if (precedes) {
-				start = str;
-				while (start[len] && start[len] != '0' && start[len] != '#')
-					len++;
-			} else {
-				start = str + strlen (str);
-				if (start > str && start[-1] == ')')
-					start--;
-				while (start > str && start[-1] != '0' && start[-1] != '#')
-					start--, len++;
-			}
-			symbol = find_symbol (start, len, precedes);
-			if (symbol != 0) {
-				gfs->format.currency_index = symbol;
-				gfs->format.force_quoted = (start[0] == '"');
-				typ = GO_FORMAT_CURRENCY;
-			}
-		}
-
-		gfs->format.use_separator = (strstr (str, "#,##0") != NULL);
-
-		if (typ == GO_FORMAT_SCIENTIFIC) {
-			const char *mend = dot ? dot : strchr (str, 'E');
-			gfs->format.use_markup = (strstr (str, "EE0") != NULL);
-			gfs->format.exponent_step = mend - str;
-			gfs->format.simplify_mantissa = mend != str && mend[-1] == '#';
-		}			
-
-		newstr = generate_format (gfs, typ);
-
-		break;
+		if (details->min_digits != 1)
+			exact = FALSE;
 	}
 
-	default:
-		newstr = NULL;
-		break;
+	if (!exact) {
+		const char *str = go_format_as_XL (fmt);
+		if (!find_builtin (str, details->family, FALSE))
+			details->family = FMT_CUSTOM;
 	}
 
-	if (newstr) {
-		/* Test the generated format. */
-		if (strcmp (str, newstr)) {
-#if 0
-			g_print ("[%s] <-> [%s]\n", str, newstr);
-#endif
-			typ = FMT_CUSTOM;
-		}
-		g_free (newstr);
-	} else {
-		const char *elem = find_builtin (str, typ, FALSE);
-		if (!elem)
-			typ = FMT_CUSTOM;
-	}
-
-	return typ;
+	return details->family;
 }
 
 
@@ -1338,18 +1026,21 @@ nfs_init (GOFormatSel *gfs)
 	gtk_widget_hide (gfs->format.preview_box);
 
 	/* setup the structure of the negative type list */
-	gfs->format.negative_types.model = gtk_list_store_new (3,
-							       G_TYPE_INT,
-							       G_TYPE_STRING,
-							       G_TYPE_STRING);
+	gfs->format.negative_types.model =
+		gtk_list_store_new (4,
+				    G_TYPE_BOOLEAN, /* red */
+				    G_TYPE_BOOLEAN, /* paren */
+				    G_TYPE_STRING,  /* format text */
+				    G_TYPE_STRING); /* colour */
 	gfs->format.negative_types.view = GTK_TREE_VIEW (gfs->format.widget[F_NEGATIVE]);
 	gtk_tree_view_set_model (gfs->format.negative_types.view,
 				 GTK_TREE_MODEL (gfs->format.negative_types.model));
-	column = gtk_tree_view_column_new_with_attributes (_("Negative Number Format"),
-							   gtk_cell_renderer_text_new (),
-							   "text",		1,
-							   "foreground",	2,
-							   NULL);
+	column = gtk_tree_view_column_new_with_attributes
+		(_("Negative Number Format"),
+		 gtk_cell_renderer_text_new (),
+		 "text", 2,
+		 "foreground", 3,
+		 NULL);
 	gtk_tree_view_append_column (gfs->format.negative_types.view, column);
 	gfs->format.negative_types.selection =
 		gtk_tree_view_get_selection (gfs->format.negative_types.view);
@@ -1388,18 +1079,24 @@ nfs_init (GOFormatSel *gfs)
 	/* Setup handler Currency & Accounting currency symbols */
 	combo = GO_COMBO_TEXT (gfs->format.widget[F_SYMBOL]);
 	if (combo != NULL) {
-		GList *ptr, *l = NULL;
+		GSList *ptr, *l = NULL;
+		const char *desc;
 
 		for (i = 0; go_format_currencies[i].symbol != NULL ; ++i)
-			l = g_list_append (l, _((gchar *)go_format_currencies[i].description));
-		l = g_list_sort (l, funny_currency_order);
+			l = g_slist_prepend (l, _((gchar *)go_format_currencies[i].description));
+		l = g_slist_sort (l, funny_currency_order);
 
 		for (ptr = l; ptr != NULL ; ptr = ptr->next)
-			go_combo_text_add_item	(combo, ptr->data);
-		g_list_free (l);
-		go_combo_text_set_text (combo,
-			_((char const *)go_format_currencies[gfs->format.currency_index].description),
-			GO_COMBO_TEXT_FROM_TOP);
+			go_combo_text_add_item (combo, ptr->data);
+		g_slist_free (l);
+
+		desc = gfs->format.details.currency
+			? gfs->format.details.currency->description
+			: NULL;
+		if (!desc)
+			desc = N_("None");
+		go_combo_text_set_text (combo, _(desc),
+					GO_COMBO_TEXT_FROM_TOP);
 		g_signal_connect (G_OBJECT (combo), "entry_changed",
 			G_CALLBACK (cb_format_currency_select), gfs);
 		gtk_label_set_mnemonic_widget (
@@ -1556,10 +1253,15 @@ go_format_sel_set_style_format (GOFormatSel *gfs,
 	study_format (gfs);
 
 	combo = GO_COMBO_TEXT (gfs->format.widget[F_SYMBOL]);
-	go_combo_text_set_text
-		(combo,
-		 _(go_format_currencies[gfs->format.currency_index].description),
-		 GO_COMBO_TEXT_FROM_TOP);
+	if (gfs->format.details.currency) {
+		const char *desc = gfs->format.details.currency
+			? gfs->format.details.currency->description
+			: NULL;
+		if (!desc)
+			desc = N_("None");
+		go_combo_text_set_text (combo, _(desc),
+					GO_COMBO_TEXT_FROM_TOP);
+	}
 
 	set_format_category_menu_from_style (gfs);
 	draw_format_preview (gfs, TRUE);
