@@ -12,9 +12,6 @@
 #include "go-rangefunc.h"
 #include "go-math.h"
 
-#include <glib/gmem.h>
-#include <glib/gmessages.h>
-
 #include <math.h>
 #include <string.h>
 #include <stdlib.h>
@@ -804,13 +801,13 @@ SUFFIX(log_fitting) (DOUBLE *xs, const DOUBLE *ys, int n,
  * @n: number of data points.
  * @affine: if true, a non-zero constant is allowed.
  * @res: output place for constant[0] and slope1[1], slope2[2],... There will be dim+1 results.
+ * @stat : non-NULL storage for additional results.
  *
  * Performs multi-dimensional linear regressions on the input points.
  * Fits to "y = b + a1 * x1 + ... ad * xd".
  *
  * Returns: #RegressionResult as above.
  **/
-
 RegressionResult
 SUFFIX(go_linear_regression) (DOUBLE **xss, int dim,
 			      const DOUBLE *ys, int n,
@@ -848,6 +845,7 @@ SUFFIX(go_linear_regression) (DOUBLE **xss, int dim,
  * @n: number of data points
  * @affine: if %TRUE, a non-one multiplier is allowed
  * @res: output place for constant[0] and root1[1], root2[2],... There will be dim+1 results.
+ * @stat : non-NULL storage for additional results.
  *
  * Performs one-dimensional linear regressions on the input points.
  * Fits to "y = b * m1^x1 * ... * md^xd " or equivalently to
@@ -855,7 +853,6 @@ SUFFIX(go_linear_regression) (DOUBLE **xss, int dim,
  *
  * Returns: #RegressionResult as above.
  **/
-
 RegressionResult
 SUFFIX(go_exponential_regression) (DOUBLE **xss, int dim,
 			const DOUBLE *ys, int n,
@@ -911,6 +908,7 @@ SUFFIX(go_exponential_regression) (DOUBLE **xss, int dim,
  * @n: number of data points
  * @affine: if %TRUE, a non-one multiplier is allowed
  * @res: output place for constant[0] and root1[1], root2[2],... There will be dim+1 results.
+ * @stat : non-NULL storage for additional results.
  *
  * Performs one-dimensional linear regressions on the input points.
  * Fits to "y = b * x1^m1 * ... * xd^md " or equivalently to
@@ -918,7 +916,6 @@ SUFFIX(go_exponential_regression) (DOUBLE **xss, int dim,
  *
  * Returns: #RegressionResult as above.
  **/
-
 RegressionResult
 SUFFIX(go_power_regression) (DOUBLE **xss, int dim,
 			const DOUBLE *ys, int n,
@@ -983,6 +980,7 @@ SUFFIX(go_power_regression) (DOUBLE **xss, int dim,
  * @n: number of data points
  * @affine: if %TRUE, a non-zero constant is allowed
  * @res: output place for constant[0] and factor1[1], factor2[2],... There will be dim+1 results.
+ * @stat : non-NULL storage for additional results.
  *
  * This is almost a copy of linear_regression and produces multi-dimensional
  * linear regressions on the input points after transforming xss to ln(xss).
@@ -994,7 +992,6 @@ SUFFIX(go_power_regression) (DOUBLE **xss, int dim,
  * 
  * Returns: #RegressionResult as above.  
  **/
-
 RegressionResult
 SUFFIX(go_logarithmic_regression) (DOUBLE **xss, int dim,
 			const DOUBLE *ys, int n,
