@@ -21,12 +21,7 @@
 #ifndef GO_FONT_H
 #define GO_FONT_H
 
-#include <glib.h>
 #include <goffice/goffice.h>
-#include <goffice/goffice-features.h>
-#include <goffice/utils/goffice-utils.h>
-#include <pango/pango-font.h>
-#include <pango/pango-context.h>
 
 G_BEGIN_DECLS
 
@@ -38,6 +33,14 @@ struct _GOFontMetrics {
 	int hyphen_width, minus_width, plus_width;
 	int E_width;
 	int hash_width;
+	int space_width;
+
+	/*
+	 * A space that is narrower than a regular space, or 0 if no such
+	 * character was found.
+	 */
+	gunichar thin_space;
+	int thin_space_width;
 };
 
 struct _GOFont {
