@@ -20,10 +20,7 @@
  */
 
 #include <goffice/goffice-config.h>
-#include "go-marker.h"
-#include "go-color.h"
-#include <goffice/math/go-math.h>
-#include <goffice/utils/go-cairo.h>
+#include <goffice/goffice.h>
 
 #include <glib/gi18n-lib.h>
 #include <gsf/gsf-impl-utils.h>
@@ -44,7 +41,7 @@ typedef struct {
 	GObjectClass	base;
 } GOMarkerClass;
 
-#define GO_MARKER_GET_CLASS(o)	(G_TYPE_INSTANCE_GET_CLASS((o),  GO_MARKER_TYPE, GOMarkerClass))
+#define GO_MARKER_GET_CLASS(o)	(G_TYPE_INSTANCE_GET_CLASS((o),  GO_TYPE_MARKER, GOMarkerClass))
 
 static char const square_path[] = 		"M-1,-1 L-1,1 1,1 1,-1 z";
 static char const diamond_path[] =		"M0,-1 L1,0 0,1 -1,0 z";
@@ -143,7 +140,7 @@ go_marker_get_shape (GOMarker const *marker)
 void
 go_marker_set_shape (GOMarker *marker, GOMarkerShape shape)
 {
-	g_return_if_fail (IS_GO_MARKER (marker));
+	g_return_if_fail (GO_IS_MARKER (marker));
 
 	if (marker->shape == shape)
 		return;
@@ -159,7 +156,7 @@ go_marker_get_outline_color (GOMarker const *marker)
 void
 go_marker_set_outline_color (GOMarker *marker, GOColor color)
 {
-	g_return_if_fail (IS_GO_MARKER (marker));
+	g_return_if_fail (GO_IS_MARKER (marker));
 	if (marker->outline_color == color)
 		return;
 	marker->outline_color = color;
@@ -174,7 +171,7 @@ go_marker_get_fill_color (GOMarker const *marker)
 void
 go_marker_set_fill_color (GOMarker *marker, GOColor color)
 {
-	g_return_if_fail (IS_GO_MARKER (marker));
+	g_return_if_fail (GO_IS_MARKER (marker));
 	if (marker->fill_color == color)
 		return;
 	marker->fill_color = color;
@@ -195,7 +192,7 @@ go_marker_get_outline_width (GOMarker const *marker)
 void
 go_marker_set_size (GOMarker *marker, int size)
 {
-	g_return_if_fail (IS_GO_MARKER (marker));
+	g_return_if_fail (GO_IS_MARKER (marker));
 	g_return_if_fail (size >= 0);
 	if (marker->size == size)
 		return;
@@ -229,7 +226,7 @@ go_marker_dup (GOMarker const *src)
 GOMarker *
 go_marker_new (void)
 {
-	return g_object_new (GO_MARKER_TYPE, NULL);
+	return g_object_new (GO_TYPE_MARKER, NULL);
 }
 
 /**
@@ -269,6 +266,7 @@ go_marker_render (GOMarker const *marker, cairo_t *cr, double x, double y, doubl
 
 	cairo_set_source_rgba (cr, GO_COLOR_TO_CAIRO (go_marker_get_outline_color (marker)));
 	cairo_set_line_width (cr, 2.0 * MARKER_OUTLINE_WIDTH);
+	cairo_set_dash (cr, NULL, 0, 0.);
 	go_cairo_emit_svg_path (cr, outline_path_raw);
 	cairo_stroke (cr);
 	cairo_restore (cr);
@@ -297,7 +295,7 @@ go_marker_create_cairo_surface (GOMarker const *marker, cairo_t *cr, double scal
 	cairo_surface_t *current_cr_surface;
 	double half_size, offset;
 
-	g_return_val_if_fail (IS_GO_MARKER (marker), NULL);
+	g_return_val_if_fail (GO_IS_MARKER (marker), NULL);
 	g_return_val_if_fail (cr != NULL, NULL);
 
 	current_cr_surface = cairo_get_target (cr);
