@@ -24,10 +24,12 @@
 #include <goffice/graph/gog-view.h>
 #include <goffice/graph/gog-renderer.h>
 #include <goffice/graph/gog-theme.h>
-#include <goffice/graph/gog-style.h>
 #include <goffice/data/go-data.h>
 #include <goffice/math/go-math.h>
 #include <goffice/utils/go-color.h>
+#include <goffice/utils/go-persist.h>
+#include <goffice/utils/go-style.h>
+#include <goffice/utils/go-styled-object.h>
 #include <goffice/app/module-plugin-defs.h>
 
 #include <glib/gi18n-lib.h>
@@ -79,11 +81,11 @@ gog_pie_series_element_get_property (GObject *obj, guint param_id,
 extern gpointer gog_pie_series_element_pref (GogPieSeriesElement *element, GOCmdContext *cc);
 static gpointer
 gog_pie_series_element_populate_editor (GogObject *gobj,
-					GogEditor *editor,
+					GOEditor *editor,
 					GOCmdContext *cc)
 {
 	GtkWidget *widget = gog_pie_series_element_pref (GOG_PIE_SERIES_ELEMENT (gobj), cc);
-	gog_editor_add_page (editor, widget, _("Settings"));
+	go_editor_add_page (editor, widget, _("Settings"));
 	return widget;
 }
 #endif
@@ -105,13 +107,13 @@ gog_pie_series_element_class_init (GogPieSeriesElementClass *klass)
 		g_param_spec_float ("separation", 
 			_("Separation"),
 			_("Amount a slice is extended as a percentage of the radius"),
-			0, G_MAXFLOAT, 0.,
-			GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
+			0, 1000, 0.,
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
 }
 
 GSF_DYNAMIC_CLASS (GogPieSeriesElement, gog_pie_series_element,
 	gog_pie_series_element_class_init, NULL /*gog_pie_series_element_init*/,
-	GOG_SERIES_ELEMENT_TYPE)
+	GOG_TYPE_SERIES_ELEMENT)
 
 /*****************************************************************************/
 
@@ -196,11 +198,11 @@ gog_pie_plot_type_name (G_GNUC_UNUSED GogObject const *item)
 extern gpointer gog_pie_plot_pref (GogPiePlot *pie, GOCmdContext *cc);
 static void
 gog_pie_plot_populate_editor (GogObject *item, 
-			      GogEditor *editor,
+			      GOEditor *editor,
 			      G_GNUC_UNUSED GogDataAllocator *dalloc,
 			      GOCmdContext *cc)
 {
-	gog_editor_add_page (editor, 
+	go_editor_add_page (editor, 
 			     gog_pie_plot_pref (GOG_PIE_PLOT (item), cc),
 			     _("Properties"));
 
@@ -233,13 +235,13 @@ gog_pie_plot_class_init (GogPlotClass *plot_klass)
 			_("Initial angle"),
 			_("Degrees clockwise from 12 O'Clock."),
 			0, G_MAXFLOAT, 0.,
-			GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
 	g_object_class_install_property (gobject_klass, PLOT_PROP_DEFAULT_SEPARATION,
 		g_param_spec_float ("default-separation", 
 			_("Default separation"),
 			_("Default amount a slice is extended as a percentage of the radius"),
 			0, G_MAXFLOAT, 0.,
-			GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
 	g_object_class_install_property (gobject_klass, PLOT_PROP_IN_3D,
 		g_param_spec_boolean ("in-3d", 
 			_("In 3d"),
@@ -251,7 +253,7 @@ gog_pie_plot_class_init (GogPlotClass *plot_klass)
 			_("Span"),
 			_("Total angle used as a percentage of the full circle"),
 			10., 100., 100.,
-			GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
 
 	{
 		static GogSeriesDimDesc dimensions[] = {
@@ -262,9 +264,8 @@ gog_pie_plot_class_init (GogPlotClass *plot_klass)
 		};
 		plot_klass->desc.series.dim = dimensions;
 		plot_klass->desc.series.num_dim = G_N_ELEMENTS (dimensions);
-		plot_klass->desc.series.style_fields = GOG_STYLE_OUTLINE | GOG_STYLE_FILL;
+		plot_klass->desc.series.style_fields = GO_STYLE_OUTLINE | GO_STYLE_FILL;
 	}
-	plot_klass->desc.num_series_min = 1;
 	plot_klass->desc.num_series_max = 1;
 	plot_klass->series_type  = gog_pie_series_get_type ();
 }
@@ -278,7 +279,7 @@ gog_pie_plot_init (GogPiePlot *pie)
 
 GSF_DYNAMIC_CLASS (GogPiePlot, gog_pie_plot,
 	gog_pie_plot_class_init, gog_pie_plot_init,
-	GOG_PLOT_TYPE)
+	GOG_TYPE_PLOT)
 
 static void
 gog_pie_plot_set_default_separation (GogPiePlot *pie, double separation)
@@ -343,11 +344,11 @@ gog_ring_plot_type_name (G_GNUC_UNUSED GogObject const *item)
 extern gpointer gog_ring_plot_pref (GogRingPlot *ring, GOCmdContext *cc);
 static void
 gog_ring_plot_populate_editor (GogObject *item,
-			       GogEditor *editor,
+			       GOEditor *editor,
 		      G_GNUC_UNUSED GogDataAllocator *dalloc,
 		      GOCmdContext *cc)
 {
-	gog_editor_add_page (editor,
+	go_editor_add_page (editor,
 			     gog_ring_plot_pref (GOG_RING_PLOT (item), cc),
 			     _("Properties"));
 }
@@ -373,9 +374,8 @@ gog_ring_plot_class_init (GogPiePlotClass *pie_plot_klass)
 			0, 100., 0.,
 			GSF_PARAM_STATIC | G_PARAM_READWRITE));
 
-	plot_klass->desc.num_series_min = 1;
 	plot_klass->desc.num_series_max = G_MAXINT;
-	plot_klass->desc.series.style_fields = GOG_STYLE_OUTLINE | GOG_STYLE_FILL;
+	plot_klass->desc.series.style_fields = GO_STYLE_OUTLINE | GO_STYLE_FILL;
 }
 
 static void
@@ -386,7 +386,7 @@ gog_ring_plot_init (GogRingPlot *ring)
 
 GSF_DYNAMIC_CLASS (GogRingPlot, gog_ring_plot,
 	gog_ring_plot_class_init, gog_ring_plot_init,
-	GOG_PIE_PLOT_TYPE)
+	GOG_TYPE_PIE_PLOT)
 
 /*****************************************************************************/
 
@@ -419,7 +419,7 @@ find_element (GogView *view, double cx, double cy, double x, double y,
 	if (theta < 0)
 		theta += 1.;
 
-	vals = go_data_vector_get_values (GO_DATA_VECTOR ((*series)->base.values[1].data));
+	vals = go_data_get_values ((*series)->base.values[1].data);
 	scale = 1 / (*series)->total;
 	for (*index = 0 ; *index < (*series)->base.num_elements; (*index)++) {
 		len = fabs (vals[*index]) * scale;
@@ -558,7 +558,7 @@ gog_pie_view_render (GogView *view, GogViewAllocation const *bbox)
 	unsigned elem, k;
 	GOPath *path;
 	GogTheme *theme = gog_object_get_theme (GOG_OBJECT (model));
-	GogStyle *style;
+	GOStyle *style;
 	GSList *ptr;
 	unsigned num_series = 0;
 	unsigned index;
@@ -584,7 +584,7 @@ gog_pie_view_render (GogView *view, GogViewAllocation const *bbox)
 
 	separation_max = .0;
 	outline_width_max = .0;
-	if ((style = gog_styled_object_get_style (GOG_STYLED_OBJECT (series))))
+	if ((style = go_styled_object_get_style (GO_STYLED_OBJECT (series))))
 		outline_width_max = gog_renderer_line_size (view->renderer, style->outline.width);
 	for (overrides = gog_series_get_overrides (GOG_SERIES (series));
 	     overrides != NULL;
@@ -592,7 +592,7 @@ gog_pie_view_render (GogView *view, GogViewAllocation const *bbox)
 		separation = GOG_PIE_SERIES_ELEMENT (overrides->data)->separation;
 		if (separation_max < separation)
 			separation_max = separation;
-		style = gog_styled_object_get_style (GOG_STYLED_OBJECT (overrides->data));
+		style = go_styled_object_get_style (GO_STYLED_OBJECT (overrides->data));
 		if (outline_width_max < style->outline.width)
 			outline_width_max = style->outline.width;
 	}
@@ -718,18 +718,22 @@ gog_pie_view_render (GogView *view, GogViewAllocation const *bbox)
 		theta = (model->initial_angle + series->initial_angle) * M_PI / 180. - M_PI / 2.;
 
 		scale = 2 * M_PI / 100 * model->span / series->total;
-		vals = go_data_vector_get_values (GO_DATA_VECTOR (series->base.values[1].data));
+		vals = go_data_get_values (series->base.values[1].data);
 
 		style = GOG_STYLED_OBJECT (series)->style;
 		if (model->base.vary_style_by_element)
-			style = gog_style_dup (style);
+			style = go_style_dup (style);
 		gog_renderer_push_style (view->renderer, style);
 
 		overrides = gog_series_get_overrides (GOG_SERIES (series));
 		for (k = 0 ; k < series->base.num_elements; k++) {
 			len = fabs (vals[k]) * scale;
-			if (!go_finite (len) || len < 1e-3)
+			if (!go_finite (len) || len < 1e-3) {
+				if ((overrides != NULL) &&
+				    (GOG_SERIES_ELEMENT (overrides->data)->index == k))
+					overrides = overrides->next;
 				continue;
+			}
 
 			gpse = NULL;
 			if ((overrides != NULL) &&
@@ -737,8 +741,8 @@ gog_pie_view_render (GogView *view, GogViewAllocation const *bbox)
 				gpse = GOG_PIE_SERIES_ELEMENT (overrides->data);
 				overrides = overrides->next;
 				gog_renderer_push_style (view->renderer,
-					gog_styled_object_get_style (
-						GOG_STYLED_OBJECT (gpse)));
+					go_styled_object_get_style (
+						GO_STYLED_OBJECT (gpse)));
 			} else if (model->base.vary_style_by_element)
 				gog_theme_fillin_style (theme, style, GOG_OBJECT (series),
 							model->base.index_num + k, FALSE);
@@ -801,7 +805,7 @@ gog_pie_view_class_init (GogViewClass *view_klass)
 
 GSF_DYNAMIC_CLASS (GogPieView, gog_pie_view,
 	gog_pie_view_class_init, NULL,
-	GOG_PLOT_VIEW_TYPE)
+	GOG_TYPE_PLOT_VIEW)
 
 /*****************************************************************************/
 
@@ -861,9 +865,8 @@ gog_pie_series_update (GogObject *obj)
 	unsigned old_num = series->base.num_elements;
 
 	if (series->base.values[1].data != NULL) {
-		vals = go_data_vector_get_values (GO_DATA_VECTOR (series->base.values[1].data));
-		len = go_data_vector_get_len (
-			GO_DATA_VECTOR (series->base.values[1].data));
+		vals = go_data_get_values (series->base.values[1].data);
+		len = go_data_get_vector_size (series->base.values[1].data);
 	}
 	series->base.num_elements = len;
 
@@ -889,7 +892,7 @@ gog_pie_series_class_init (GObjectClass *gobject_klass)
 
 	series_parent_klass = g_type_class_peek_parent (gobject_klass);
 	gog_klass->update = gog_pie_series_update;
-	series_klass->series_element_type = GOG_PIE_SERIES_ELEMENT_TYPE;
+	series_klass->series_element_type = GOG_TYPE_PIE_SERIES_ELEMENT;
 
 	gobject_klass->set_property = gog_pie_series_set_property;
 	gobject_klass->get_property = gog_pie_series_get_property;
@@ -910,7 +913,7 @@ gog_pie_series_class_init (GObjectClass *gobject_klass)
 
 GSF_DYNAMIC_CLASS (GogPieSeries, gog_pie_series,
 	   gog_pie_series_class_init, NULL,
-	   GOG_SERIES_TYPE)
+	   GOG_TYPE_SERIES)
 
 G_MODULE_EXPORT void
 go_plugin_init (GOPlugin *plugin, GOCmdContext *cc)
