@@ -29,9 +29,9 @@ G_BEGIN_DECLS
 typedef GogLinRegCurve  GogPolynomRegCurve;
 typedef GogLinRegCurveClass GogPolynomRegCurveClass;
 
-#define GOG_POLYNOM_REG_CURVE_TYPE	(gog_polynom_reg_curve_get_type ())
-#define GOG_POLYNOM_REG_CURVE(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_POLYNOM_REG_CURVE_TYPE, GogPolynomRegCurve))
-#define GOG_IS_POLYNOM_REG_CURVE(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_POLYNOM_REG_CURVE_TYPE))
+#define GOG_TYPE_POLYNOM_REG_CURVE	(gog_polynom_reg_curve_get_type ())
+#define GOG_POLYNOM_REG_CURVE(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_TYPE_POLYNOM_REG_CURVE, GogPolynomRegCurve))
+#define GOG_IS_POLYNOM_REG_CURVE(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_TYPE_POLYNOM_REG_CURVE))
 
 GType gog_polynom_reg_curve_get_type (void);
 void  gog_polynom_reg_curve_register_type (GTypeModule *module);
