@@ -24,8 +24,8 @@
 #include "gog-logfit.h"
 #include <goffice/data/go-data.h>
 #include <goffice/graph/gog-series-impl.h>
-#include <goffice/utils/go-math.h>
-#include <goffice/utils/go-rangefunc.h>
+#include <goffice/math/go-math.h>
+#include <goffice/math/go-rangefunc.h>
 #include <glib/gi18n-lib.h>
 
 #include <gsf/gsf-impl-utils.h>
@@ -165,7 +165,7 @@ gog_log_fit_curve_init (GogRegCurve *model)
 
 GSF_DYNAMIC_CLASS (GogLogFitCurve, gog_log_fit_curve,
 	gog_log_fit_curve_class_init, gog_log_fit_curve_init,
-	GOG_REG_CURVE_TYPE)
+	GOG_TYPE_REG_CURVE)
 
 /* Plugin initialization */
 
